Stan Math Library: stan/math/fwd/scal/fun/to_fvar.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

to_fvar.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_TO_FVAR_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_TO_FVAR_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 namespace stan {
7 namespace math {
8
9 template<typename T>
10 inline
11 fvar<T>
12 to_fvar(const T& x) {
13 return fvar<T>(x);
14 }
15
16 template<typename T>
17 inline
18 fvar<T>
19 to_fvar(const fvar<T>& x) {
20 return x;
21 }
22
23 }
24 }
25 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::to_fvar
std::vector< fvar< T > > to_fvar(const std::vector< T > &v)
Definition: to_fvar.hpp:14
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.